auto-execute-command auto-fill-mode /tmp/\{Re,article,rnmail,pn\}
auto-execute-command show-match .*\.[lchyf]$\|.*\.lisp$\|.*\.scm$
auto-execute-command c-mode .*\.[chy]$
auto-execute-command lisp-mode .*\.l$\|.*\.lisp$\|.*\.scm$
bind-to-key pause-jove ^[S
bind-to-key pause-jove ^[s
set process-prompt ^[^%$#]*[%$#] 
process-bind-to-key interrupt-process ^C
process-bind-to-key process-newline ^M
make-keymap ansi-codes
bind-keymap-to-key ansi-codes ^[[
bind-keymap-to-key ansi-codes ^[O
bind-to-key previous-line ^[[A
bind-to-key next-line ^[[B
bind-to-key forward-character ^[[C
bind-to-key backward-character ^[[D
bind-to-key previous-line ^[OA
bind-to-key next-line ^[OB
bind-to-key forward-character ^[OC
bind-to-key backward-character ^[OD
